@@ -32,12 +32,16 @@ MESSAGE_READ_TIMEOUT_SEC = 30.0
 BROKER_SOCKET_FILE = '/var/run/ovirt-hosted-engine-ha/broker.socket'
 
 ENGINE_SETUP_CONF_FILE = '/etc/ovirt-hosted-engine/hosted-engine.conf'
+CACHED_ENGINE_SETUP_CONF_FILE = \
+    '/var/lib/ovirt-hosted-engine-ha/hosted-engine.conf'
 NOTIFY_CONF_FILE_35 = '/etc/ovirt-hosted-engine-ha/broker.conf'
 NOTIFY_CONF_FILE = '/var/lib/ovirt-hosted-engine-ha/broker.conf'
 ANSWER_FILE_35 = '/etc/ovirt-hosted-engine/answers.conf'
 VM_CONF_FILE_35 = '/etc/ovirt-hosted-engine/vm.conf'
 
 LOCAL_VM_CONF_PATH = '/var/run/ovirt-hosted-engine-ha/vm.conf'
+LOCAL_VM_CONF_PATH_FALLBACK = \
+    '/var/run/ovirt-hosted-engine-ha/vm.conf.fallback'
 
 HA_AGENT_CONF_FILE = '/var/lib/ovirt-hosted-engine-ha/ha.conf'
 
